"use client";

import { Transaction } from "@/lib/db";
import {
  Chart as ChartJS,
  CategoryScale,
  LinearScale,
  BarElement,
  Title,
  Tooltip,
  Legend,
  Scale,
} from "chart.js";
import { Bar } from "react-chartjs-2";

ChartJS.register(
  CategoryScale,
  LinearScale,
  BarElement,
  Title,
  Tooltip,
  Legend
);

interface StatsTabProps {
  transactions: Transaction[];
}

export default function StatsTab({ transactions }: StatsTabProps) {
  // Agrupar transacciones por categoría
  const categoryTotals = transactions.reduce((acc, transaction) => {
    const category = transaction.category;
    if (!acc[category]) {
      acc[category] = {
        income: 0,
        expenses: 0,
      };
    }
    if (transaction.type === "INCOME") {
      acc[category].income += transaction.amount;
    } else {
      acc[category].expenses += transaction.amount;
    }
    return acc;
  }, {} as Record<string, { income: number; expenses: number }>);

  const chartData = {
    labels: Object.keys(categoryTotals),
    datasets: [
      {
        label: "Ingresos",
        data: Object.values(categoryTotals).map((cat) => cat.income),
        backgroundColor: "rgba(34, 197, 94, 0.8)",
        borderColor: "rgba(34, 197, 94, 1)",
        borderWidth: 1,
      },
      {
        label: "Gastos",
        data: Object.values(categoryTotals).map((cat) => cat.expenses),
        backgroundColor: "rgba(239, 68, 68, 0.8)",
        borderColor: "rgba(239, 68, 68, 1)",
        borderWidth: 1,
      },
    ],
  };

  const chartOptions = {
    responsive: true,
    maintainAspectRatio: false,
    plugins: {
      legend: {
        position: "top" as const,
      },
      title: {
        display: true,
        text: "Estadísticas por categoría",
      },
    },
    scales: {
      y: {
        beginAtZero: true,
        ticks: {
          callback: function (this: Scale, value: number | string) {
            return `$${Number(value).toFixed(2)}`;
          },
        },
      },
    },
  };

  return (
    <div className="space-y-6">
      <div className="bg-gray-800 rounded-2xl p-6">
        <h2 className="text-xl font-semibold mb-4 text-white">
          Estadísticas por categoría
        </h2>
        <div className="h-80">
          <Bar data={chartData} options={chartOptions} />
        </div>
      </div>

      <div className="bg-gray-800 rounded-2xl p-6">
        <h2 className="text-xl font-semibold mb-4 text-white">
          Resumen de categorías
        </h2>
        <div className="space-y-4">
          {Object.entries(categoryTotals).map(([category, totals]) => (
            <div key={category} className="bg-gray-700 rounded-xl p-4">
              <h3 className="text-lg font-medium text-white mb-2">
                {category}
              </h3>
              <div className="grid grid-cols-2 gap-4">
                <div>
                  <p className="text-sm text-gray-400">Ingresos</p>
                  <p className="text-lg font-semibold text-green-500">
                    ${totals.income.toFixed(2)}
                  </p>
                </div>
                <div>
                  <p className="text-sm text-gray-400">Gastos</p>
                  <p className="text-lg font-semibold text-red-500">
                    ${totals.expenses.toFixed(2)}
                  </p>
                </div>
              </div>
            </div>
          ))}
        </div>
      </div>
    </div>
  );
}
